import XCTest
@testable import HTTPNetworking

final class HttpRequestTests: XCTestCase {
    let baseUrl = "http://example.com"

    func testUrlExtensionWithNoPathComponents() {
        let request = TestRequest(baseUrl: baseUrl, pathComponents: [], method: .get, headers: [:])

        XCTAssertEqual(baseUrl, request.url.absoluteString)
        XCTAssertEqual(.get, request.method)
    }

    func testUrlExtensionWithPathComponents() {
        let request = TestRequest(baseUrl: baseUrl, pathComponents: ["foo", "bar"], method: .post, headers: [:])

        XCTAssertEqual(baseUrl + "/foo/bar", request.url.absoluteString)
        XCTAssertEqual(.post, request.method)
    }

    func testUrlExtensionWithPathComponentsAndSlashAfterBaseUrl() {
        let request = TestRequest(baseUrl: baseUrl + "/", pathComponents: ["foo", "bar"], method: .put, headers: [:])

        XCTAssertEqual(baseUrl + "/foo/bar", request.url.absoluteString)
        XCTAssertEqual(.put, request.method)
    }
}
