import Foundation
import HTTPMockHelpers
import XCTest
import Combine
@testable import HTTPNetworking

final class NetworkSessionTests: XCTestCase {

    let session: NetworkSession = URLSession.mockSession
    let baseUrl = "http://example.com"
    private var cancelBag = Set<AnyCancellable>()

    override class func setUp() {
        super.setUp()
        HTTPNetworkingConfig.isDebugPrintingEnabled = true
    }

    func testDataTaskPublisher() {
        let request = TestRequest(
            baseUrl: baseUrl,
            pathComponents: ["test", "mock"],
            method: .get,
            query: nil,
            body: nil,
            headers: [:]
        )

        let url = URL(string: "\(baseUrl)/test/mock")
        URLSessionStubResults.resultsForUrls[url] = .dataResponse(
            data: "{\"title\":\"Test\",\"text\":\"Text\"}".data(using: .utf8)!,
            response: URLSessionStubResponses.response(url: url!)!
        )

        let expect = XCTestExpectation()
        session.dataTaskPublisher(for: request)
            .sink(
                receiveCompletion: { completion in
                    switch completion {
                    case .failure:
                        XCTFail("Should not fail!")
                    case .finished:
                        expect.fulfill()
                    }
                },
                receiveValue: { response in
                    XCTAssertEqual("Test", response.example.title)
                    XCTAssertEqual("Text", response.example.text)
                }
            )
            .store(in: &cancelBag)
        wait(for: [expect], timeout: 1.0)
    }
}
