// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation
import MaternityServices
import ConfigurationServices
import FeedbackServices
import PDFServices

final class ApiConfiguration {
    var baseUrl: String {
        switch App.buildConfiguration {
        case .debug,
             .test,
             .testMock,
             .development:
            return "https://graviditet-test0.nspop.dk:8443/gmapp"

        case .release:
            return "https://gm.insp.nsp.dk"

        case .unknown:
            fatalError("App was started with unknown build configuration 🤯")
        }
    }
}

// MARK: - ChecklistApiConfiguration
extension ApiConfiguration: ConfigurationApiConfiguration {
    var configurationBaseUrl: String { "\(baseUrl)/configuration/v1" }
}

// MARK: - MaternityApiConfiguration
extension ApiConfiguration: MaternityApiConfiguration {
    var maternityBaseUrl: String { "\(baseUrl)/maternity/v1" }
}

// MARK: - FeedbackApiConfiguration
extension ApiConfiguration: FeedbackApiConfiguration {
    var feedbackBaseUrl: String { "\(baseUrl)/feedback/v1" }
}

// MARK: - PDFApiConfiguration
extension ApiConfiguration: PDFApiConfiguration {
    var pdfBaseUrl: String { "\(baseUrl)/pdf/v1" }
}
