// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation
import GMAppData

extension DataCard : Identifiable {
    public var id: String {
        episodeOfCareIdentifier
    }

    private var expectedDeliverySection: ExpectedDateOfDeliverySection? {
        expectedDateOfDeliverySection
    }

    var userName: String {
        recordTarget.name.fullName
    }

    var weekProgress: String {
        expectedDeliverySection?.gestationAge ?? Localizable.common_unknown()
    }

    var trimester: Int? {
        expectedDeliverySection?.trimester
    }

    var months: Double? {
        expectedDeliverySection?.monthsIntoPregnancy
    }

    var dueDate: Date? {
        expectedDeliverySection?.activeDueDate
    }

    var week: Int? {
        expectedDeliverySection?.week
    }

    var isEnded: Bool {
        documentStatus == .closed
    }

    var isActive: Bool {
        documentStatus == .new || documentStatus == .active
    }
}

extension DataCard: RadioListPickerItem {
    var title: String {
        #warning("Ended date!")
        if let date = Date() as? Date, isEnded {
            return Localizable.overview_pick_pregnancy_ended_date(OverviewDateFormatter.string(from: date))
        } else if let date = dueDate, !isEnded {
            return Localizable.overview_pick_pregnancy_active_date(OverviewDateFormatter.string(from: date))
        } else {
            return Localizable.common_missing_data()
        }
    }
}

extension Collection where Element == DataCard {
    func mostRecentDataCard() -> DataCard? {
        let dataCard: DataCard?
        if let activeDataCard: DataCard = self.first(where: { $0.isActive }) {
            dataCard = activeDataCard
        } else if let mostRecent = self
            .max(by: { $0.modifiedTime < $1.modifiedTime }) {
            dataCard = mostRecent
        } else {
            dataCard = self.first
        }
        return dataCard

    }
}
