// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation
import UIData
import GMAppData

extension ScanningObservationTableMotherRows : ObservationTableDataTableCellGenerator, ObservationTableActivity, DictionaryPresenter {
    func dataTableCell(
        for measurementType: JournalTableScanMotherMeasurementType,
        measurementCellId: String,
        activityId: String?,
        navigateToActivity: @escaping ((String) -> Void)
    ) -> DataTableCell {
        let dataTableCell: DataTableCell
        switch measurementType {
        case .amnioticFluid:
            dataTableCell = .textWithOptionalValue(id: measurementCellId, value: self.amnioticFluid)
        case .flow:
            dataTableCell = .textWithOptionalValue(id: measurementCellId, value: self.flow)
        case .cervix:
            dataTableCell = .textWithOptionalValue(id: measurementCellId, value: self.cervix?.valueWithUnit)
        case .dvp:
            dataTableCell = .textWithOptionalValue(id: measurementCellId, value: self.dvp?.valueWithUnit)
        case .conclusion:
            if let conclusion = conclusion?.nilIfEmpty {
                dataTableCell = DataTableCell(
                    id: measurementCellId,
                    value: Localizable.common_show(),
                    type: .primaryButton({
                        showDictionaryView(title: measurementType.title, text: conclusion)
                    })
                )
            } else {
                dataTableCell = .textWithOptionalValue(id: measurementCellId, value: nil)
            }
        case .activity:
            dataTableCell = DataTableCell(
                id: measurementCellId,
                value: Localizable.common_show(),
                type: .primaryButton({
                    guard let activityId = activityId else {
                        return
                    }
                    navigateToActivity(activityId)
                }))
        }
        return dataTableCell
    }

    static func emptyTableInstance(activity: ObservationTableActivity) -> ScanningObservationTableMotherRows {
        ScanningObservationTableMotherRows(
            activityId: activity.activityId,
            date: activity.date,
            gestationAge: nil,
            weeksIntoPregnancy: nil,
            amnioticFluid: nil,
            flow: nil,
            cervix: nil,
            dvp: nil,
            conclusion: nil
        )
    }
}
