// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation
import GMAppData
import ErrorData
import Combine

protocol MaternityDataEnvironmentStore: AnyObject, UserDataStore {
    var maternities: [DataCard]? { get }
    var selectedMaternity: DataCard? { get }
    var dateOfBirthForSelectedMaternity: Date? { get }

    func changeSelectedMaternity(_ maternity: DataCard) -> AnyPublisher<Void, ServiceError>

    func changeDateOfBirthForSelectedMaternity(_ date: Date?) -> AnyPublisher<Void, ServiceError>

    /// Fetches all available data cards for user, sets the selected maternity and loads date of birth for the selected maternity.
    ///
    /// The implementation is protected against multiple calls at the same time, by returning the same publisher to all requesters while loading.
    func requestUpdate() -> AnyPublisher<Void, ServiceError>
}
