// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation
import CMSData

struct Checklist: Identifiable {
    let id: Int
    let title: String
    let description: String?
    let items: [Item]

    static func create(from content: ChecklistContent, checkedIds: [String]) -> Checklist {
        Checklist(
            id: content.id,
            title: content.title,
            description: content.text,
            items: content.items.map({ contentItem in
                Item.create(
                    from: contentItem,
                    isChecked: checkedIds.contains(contentItem.id)
                )
            })
        )
    }

    struct Item: Identifiable {
        let id: String
        let title: String
        let text: String?
        var isChecked: Bool

        static func create(from content: ChecklistItemContent, isChecked: Bool) -> Item {
            Item(
                id: content.id,
                title: content.title,
                text: content.text?.nilIfEmpty,
                isChecked: isChecked
            )
        }
    }
}
