// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI
import GMAppData

struct AppointmentDetailJournalNotesView: View {
    let note: Note?
    var body: some View {
        if let note = note {
            VStack(alignment: .leading, spacing: 10) {
                if let title = note.title {
                    Text(title)
                        .applyTextStyle(fontStyle: .h2)
                }
                Text(note.content)
                    .applyTextStyle(fontStyle: .body)
                DefaultDivider()
                Text(Localizable.appointment_details_measurement_author(
                    note.authorName ?? Localizable.common_missing_data(),
                    AppointmentsView.dateAndTimeFormatter.optionalFormatWithFallback(from: note.date)
                ))
                .applyTextStyle(fontStyle: .info, textColor: R.color.greyText.color())
                .padding(.bottom)
            }
        } else {
            EmptyStateView(
                title: Localizable.appointment_details_journalnotes_empty_title(),
                text: Localizable.appointment_details_journalnotes_empty_description()
            )
        }
    }
}

#if DEBUG
struct AppointmentDetailJournalNotesView_Previews: PreviewProvider {
    static var previews: some View {
        AppointmentDetailJournalNotesView(
            note: loadFinishedActivities().first!.note!
        )
    }
}
#endif
