// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI
import CMSData
import GMAppData
import UIData

struct AppointmentDetailMeasurementsTable: View {
    let title: String
    let observations: [Observation]
    let dictionary: CMSDictionary

    var body: some View {
        VStack(alignment: .leading) {
            Text(title)
                .applyTextStyle(fontStyle: .h4)
            TwoColumnDataTable(
                rows: observations
                    .flatMap({ $0.values })
                    .map({ (ov: ObservationValues) -> [DataTableCell] in
                        let cellIdPrefix = ov.name ?? UUID().uuidString
                        return [
                            DataTableCell(
                                id: "\(cellIdPrefix)_name",
                                value: ov.name ?? Localizable.common_missing_data(),
                                type: cellType(for: ov)
                            ),
                            DataTableCell(
                                id: "\(cellIdPrefix)_value",
                                value: "\(ov.value) \(ov.unit ?? "")",
                                type: .text
                            )
                        ]
                    })
            )
            if let latestChange = observations.latestChange {
                Text(Localizable.appointment_details_measurement_author(
                    latestChange.enteredBy,
                    AppointmentsView.dateAndTimeFormatter.string(from: latestChange.dateOfMeasurement)
                ))
                .applyTextStyle(fontStyle: .info, textColor: R.color.greyText.color())
            }
        }
    }

    private func cellType(for value: ObservationValues) -> DataTableCellType {
        guard let name: String = value.name else {
            return .boldText
        }
        return .potentialDictionaryCellType(
            title: name,
            dictionary: dictionary,
            fallback: .boldText
        )
    }
}

#if DEBUG
struct AppointmentDetailMeasurementsTable_Previews: PreviewProvider {
    static var previews: some View {
        AppointmentDetailMeasurementsTable(
            title: "Test",
            observations:  loadPreviewCarePlan()
                .activities!
                .first!
                .observations ?? [],
            dictionary: CMSDictionary.empty()
        )
    }
}
#endif
