// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI
import GMAppData

struct ActivityCardView: View {    
    let activity: Activity

    var body: some View {
        BasicCardView {
            HStack {
                VStack(alignment: .leading) {
                    VStack(alignment: .leading, spacing: 0) {
                        Text(activity.title)
                            .applyTextStyle(fontStyle: .h3)
                            .fixedSize(horizontal: false, vertical: true)
                            .padding(.bottom, 4)
                        
                        if let from = activity.plannedTime?.from, activity.status == .finished {
                            Text(AppointmentsView.dateFormatter.string(from: from))
                                .applyTextStyle(fontStyle: .h5)
                        } else if let gestationWeek = activity.gestationWeek {
                            Text(Localizable.appointment_week_label(gestationWeek))
                                .applyTextStyle(fontStyle: .h5)
                        }
                    }
                }

                Spacer()

                VStack(alignment: .trailing) {
                    if activity.note != nil || activity.observations?.isEmpty == false {
                        Image(R.image.icons.journal.info.name)
                            .renderingMode(.template)
                            .foregroundColor(R.color.smallTextButton.color())
                    }
                    Spacer()
                    ChevronRightView()
                        .padding(.trailing, 2)
                }
            }
            .padding()
        }
    }
}

#if DEBUG
struct ActivityCardView_Previews: PreviewProvider {
    static var previews: some View {
        ScrollView {
            VStack(spacing: 20) {
                Group {
                    ActivityCardView(
                        activity: loadPreviewCarePlan()
                            .activities!
                            .statusSet()
                            .finished.first!
                    )
                    ActivityCardView(
                        activity: loadPreviewCarePlan()
                            .activities!
                            .statusSet()
                            .planned.first!
                    )
                }
                .environment(\.colorScheme, .dark)

                Group {
                    ActivityCardView(
                        activity: loadPreviewCarePlan()
                            .activities!
                            .statusSet()
                            .finished.first!
                    )
                    ActivityCardView(
                        activity: loadPreviewCarePlan()
                            .activities!
                            .statusSet()
                            .planned.first!
                    )
                }
                .environment(\.colorScheme, .light)
            }
            .padding()
        }
    }
}
#endif
