// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI
import GMAppData

private let defaultTopPadding: CGFloat = 10

struct ActivityTimelineEntryView<Content: View>: View {

    let lineColor: Color
    let dotColor: Color
    let topPadding: CGFloat
    let content: Content

    @State private var height: CGFloat = 0

    init(lineColor: Color, dotColor: Color = R.color.primary.color(), topPadding: CGFloat = defaultTopPadding, @ViewBuilder content: () -> Content) {
        self.lineColor = lineColor
        self.dotColor = dotColor
        self.topPadding = topPadding
        self.content = content()
    }

    var body: some View {
        HStack(alignment: .top) {
            VStack(alignment: .leading, spacing: 0) {
                VerticalLineView(color: lineColor)
                    .frame(height: 30 + (topPadding - defaultTopPadding))

                AppointmentDotView(color: dotColor)
                VerticalLineView(color: lineColor)
            }
            .frame(minHeight: height)

            content
                .padding(.top, topPadding)
                .padding(.bottom, 10)
                .onSizeChanged(ContentSizeKey.self) { (size) in
                    height = size.height
                }
        }
        .padding(.horizontal)
    }
}

private struct ContentSizeKey: SizeReaderKey {
    static var defaultValue: CGSize = .zero
}

struct ActivityTimelineEntryView_Previews: PreviewProvider {
    static var previews: some View {
        ScrollView {
            VStack(spacing: 0) {
                ActivityTimelineEntryView(
                    lineColor: .pink
                ) {
                    ActivityEntryCardView(
                        activity: loadFinishedActivities().first!
                    )
                }
                ActivityTimelineEntryView(
                    lineColor: .blue
                ) {
                    ActivityEntryCardView(
                        activity: loadFinishedActivities().first!
                    )
                }
            }
        }
    }
}
