// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct DocumentationView: View {
    @ObservedObject private var viewModel = ViewModel()

    var body: some View {
        ScrollView {
            VStack(spacing: 16) {
                CircleImageHeaderView(
                    title: viewModel.title,
                    text: Localizable.more_documentation_description(),
                    imageUrl: nil,
                    image: Image(R.image.icons.more.documentation.name)
                )
                .padding(.vertical)
                DocumentationButtonCard(
                    title: Localizable.more_documentation_to_workplace_title(),
                    description: Localizable.more_documentation_to_workplace_body(),
                    buttonText: Localizable.more_documentation_to_workplace_button_title(),
                    buttonAction: viewModel.sendWorkplaceDocument
                )
                DocumentationButtonCard(
                    title: Localizable.more_documentation_send_data_title(),
                    description: Localizable.more_documentation_send_data_description(),
                    buttonText: Localizable.more_documentation_send_data_button(),
                    buttonAction: viewModel.sendDocument
                )
                DocumentationStoragePeriodCard()
            }
            .padding()
        }
        .notImplementedAlert(isPresented: $viewModel.showNotImplemented)
        .navigationBarTitle(Text(viewModel.title), displayMode: .inline)
    }
}

struct DocumentationView_Previews: PreviewProvider {
    static var previews: some View {
        DocumentationView()
    }
}
