// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation
import Rswift
import SwiftUI

extension MoreView {
    enum ListItem: String, CaseIterable, Identifiable {
        case documentation
        case support
        case settings
        case rateTheApp

        var id: String {
            rawValue
        }

        var title: String {
            switch self {
            case .documentation: return Localizable.more_documentation_title()
            case .support: return Localizable.more_support_title()
            case .settings: return Localizable.more_settings_title()
            case .rateTheApp: return Localizable.more_rating_title()
            }
        }

        var image: ImageResource {
            switch self {
            case .documentation: return R.image.icons.more.documentation
            case .support: return R.image.icons.more.support
            case .settings: return R.image.icons.more.settings
            case .rateTheApp: return R.image.icons.more.rate
            }
        }

        var description: String {
            switch self {
            case .documentation: return Localizable.more_documentation_description()
            case .support: return Localizable.more_support_description()
            case .settings: return Localizable.more_settings_description()
            case .rateTheApp: return Localizable.more_rating_description()
            }
        }

        @ViewBuilder
        var destinationView: some View {
            switch self {
            case .documentation:
                DocumentationView()
            case .support:
                SupportView()
            case .settings:
                SettingsView()
            case .rateTheApp:
                RateTheAppView(isPresentedAsSheet: .constant(false))
            }
        }

    }
}
