// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct SettingsEnableBiometricLoginView: View {

    @ObservedObject private var viewModel = ViewModel()
    @Environment(\.presentationMode) private var presentationMode

    var body: some View {
        NavigationView {
            VStack {
                PINTitleView(
                    pinCodeLength: viewModel.pinCodeLength,
                    isBiometricLoginAvailable: false,
                    title: viewModel.biometricName,
                    infoText: Localizable.ios_biometric_pincode_description(viewModel.biometricName),
                    wrongCodeText: Localizable.login_error_wrong_pin_code(),
                    pinCode: $viewModel.pinCode,
                    isLoading: $viewModel.isLoading,
                    wrongCode: $viewModel.wrongCode,
                    biometricLoginWasActivated: .constant(false),
                    shouldResetWrongPinCodeState: $viewModel.shouldResetWrongPinCodeState
                )
                viewModel.alertViewsForErrorStates()
            }
            .alert(isPresented: $viewModel.showSuccessAlert, content: {
                Alert(
                    title: Text(Localizable.ios_alert_biometric_enabled_title(viewModel.biometricName)),
                    message: Text(Localizable.ios_alert_biometric_enabled_description(viewModel.biometricName)),
                    dismissButton: .default(Text(Localizable.common_ok()), action: {
                        presentationMode.wrappedValue.dismiss()
                    }))
            })
            .navigationBarTitle(Text(Localizable.more_settings_title()), displayMode: .inline)
            .navigationBarItems(trailing: CloseModalButton(action: {
                presentationMode.wrappedValue.dismiss()
            }))
        }
    }
}

struct SettingsEnableBiometricLoginView_Previews: PreviewProvider {
    static var previews: some View {
        SettingsEnableBiometricLoginView()
    }
}
