// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct OverviewPregnancyPickerView: View, ScreenTrackable {
    @ObservedObject var viewModel: ViewModel
    @Environment(\.presentationMode) var presentationMode

    var body: some View {
        NavigationView {
            VStack {
                Text(Localizable.overview_pick_pregnancy_description())
                    .applyTextStyle(fontStyle: .body)
                ScrollView {
                    RadioListPickerView(
                        sections: viewModel.sections,
                        selectedItemId: $viewModel.selectedItemId
                    )
                }
                Spacer()
                LoadingButton(
                    title: Localizable.overview_pick_pregnancy_select_button(),
                    isLoading: viewModel.isLoading,
                    action: {
                        viewModel.save()
                    }
                )
                .disabled(viewModel.selectedItemId == nil)
            }
            .padding()
            .navigationBarTitle(Text(Localizable.overview_pick_pregnancy_title()), displayMode: .inline)
            .navigationBarItems(trailing: CloseModalButton(action: {
                presentationMode.wrappedValue.dismiss()
            }))
            .alert(for: $viewModel.error)
            .onReceive(viewModel.$didSave, perform: { didSave in
                if didSave {
                    presentationMode.wrappedValue.dismiss()
                }
            })
        }
        .screenTracking(screenTrackingName)
        .protectedAppearanceEvents(
            onAppear: viewModel.reset,
            onDisappear: viewModel.reset
        )
    }
}

struct OverviewPregnancyPickerView_Previews: PreviewProvider {
    static var previews: some View {
        OverviewPregnancyPickerView(
            viewModel: OverviewPregnancyPickerView.ViewModel()
        )
    }
}
