// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct OverviewHeaderDateCard: View {
    @Environment(\.isEnabled) private var isEnabled: Bool

    let title: String?
    let date: Date?
    let minWidth: CGFloat
    let action: () -> Void

    // Using UIImage to get size
    private var image: UIImage {
        date == nil ? R.image.icons.overview.date_add()!
            : R.image.icons.overview.date_edit()!
    }

    private var imageWidth: CGFloat {
        image.size.width
    }

    private var accessibilityTextForDate: String {
        if let date = date {
            return OverviewDateFormatter.string(from: date)
        } else {
            return Localizable.common_missing_data_accessibility_label()
        }
    }

    var body: some View {
        Button(
            action: action,
            label: {
                OverviewHeaderCard(title: title) {
                    HStack {
                        if isEnabled && date == nil {
                            Rectangle()
                                .frame(width: imageWidth, height: 0)
                        }
                        if let date = date {
                            Text(OverviewDateFormatter.string(from: date))
                                .applyTextStyle(fontStyle: .h3)
                        } else {
                             Text(Localizable.common_missing_data())
                                .applyTextStyle(fontStyle: .h3)
                                .frame(minWidth: minWidth - imageWidth * 2)
                        }
                        if isEnabled {
                            Image(uiImage: image)
                                .renderingMode(.template)
                                .foregroundColor(R.color.primary.color())
                        }
                    }
                    .frame(
                        minWidth: minWidth,
                        minHeight: Metrics.Sizes.overviewHeaderValueHeight
                    )
                }
            }
        )
        .disabled(!isEnabled)
        .accessibility(label: Text("\(title ?? ""): \(accessibilityTextForDate)"))
        .accessibility(removeTraits: isEnabled ? [] : [.isButton])
    }
}

struct OverviewHeaderDateCard_Previews: PreviewProvider {
    static var previews: some View {
        VStack {
            OverviewHeaderDateCard(
                title: "Test",
                date: Date(),
                minWidth: 130,
                action: { }
            )
            OverviewHeaderDateCard(
                title: "Test",
                date: nil,
                minWidth: 130,
                action: {}
            )
            .disabled(true)
            OverviewHeaderDateCard(
                title: "Test",
                date: nil,
                minWidth: 166,
                action: {}
            )
        }
        .frame(width: 200)
    }
}
