// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct OnboardingConsentView: View, ScreenTrackable {
    @Environment(\.presentationMode) var presentationMode
    @ObservedObject var viewModel = OnboardingConsentView.ViewModel()

    var body: some View {
        NavigationView {
            VStack(spacing: 0) {
                ScrollView {
                    VStack(alignment: .leading, spacing: 10) {
                        Text(Localizable.agreement_header1())
                            .applyTextStyle(fontStyle: .h2)
                        Text(Localizable.agreement_text1())
                            .applyTextStyle(fontStyle: .body)
                        Text(Localizable.agreement_header2())
                            .applyTextStyle(fontStyle: .h2)
                        Text(Localizable.agreement_text2())
                            .applyTextStyle(fontStyle: .body)
                    }
                    .padding()
                }
                BottomContainerCardView {
                    PrimaryButton(title: Localizable.agreement_button_text()) {
                        viewModel.performOpenIDConnectLogin()
                    }
                    .padding([.leading, .trailing, .bottom])
                    .accessibility(identifier: "consent_accept")
                }
                .alert(isPresented: $viewModel.oidcLoginFailed, content: {
                    Alert(
                        title: Text(Localizable.common_alert_title_error()),
                        message: Text(Localizable.common_alert_message_generic()),
                        dismissButton: .default(Text(Localizable.common_ok()))
                    )
                })
            }
            .navigationBarTitle(Text(Localizable.agreement_title()), displayMode: .inline)
            .navigationBarItems(trailing: CloseModalButton(action: {
                presentationMode.wrappedValue.dismiss()
            }))
            .screenTracking(screenTrackingName)
        }
        .navigationViewStyle(StackNavigationViewStyle())
    }
}

struct OnboardingConsentView_Previews: PreviewProvider {
    static var previews: some View {
        OnboardingConsentView()
    }
}
