// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import XCTest
import GMAppData
@testable import MinGraviditet

final class DataCardTests: XCTestCase {
    func testMostRecentDataCardWithNoActive() throws {
        let date1 = Date().date(byAdding: .day, value: -2)!
        let date2 = Date().date(byAdding: .day, value: -5)!
        let date3 = Date().date(byAdding: .day, value: -1)!

        let dataCards = [
            DataCard.empty(modifiedTime: date1, status: .closed),
            DataCard.empty(modifiedTime: date2, status: .closed),
            DataCard.empty(modifiedTime: date3, status: .closed)
        ]
        XCTAssertEqual(dataCards.mostRecentDataCard()?.modifiedTime, date3)
    }

    func testMostRecentDataCardWithActive() throws {
        let date1 = Date().date(byAdding: .day, value: -2)!
        let date2 = Date().date(byAdding: .day, value: -5)!
        let date3 = Date().date(byAdding: .day, value: -1)!

        let dataCards = [
            DataCard.empty(modifiedTime: date1, status: .closed),
            DataCard.empty(modifiedTime: date2, status: .active),
            DataCard.empty(modifiedTime: date3, status: .closed)
        ]
        XCTAssertEqual(dataCards.mostRecentDataCard()?.modifiedTime, date2)
    }
}


private extension DataCard {
    static func empty(modifiedTime: Date, status: DocumentStatus) -> DataCard {
        DataCard(
            modifiedTime: modifiedTime,
            author: HealthCareOrganization(name: "", sorId: ""),
            dirty: nil,
            episodeOfCareIdentifier: UUID().uuidString,
            documentUniqueId: nil,
            version: nil,
            documentStatus: status,
            recordTarget: CprIdentifiedPerson(name: PersonName(firstNames: [], middleNames: [], lastName: ""), identifier: UUID().uuidString),
            childPartnerSection: nil,
            languageSection: nil,
            bodyMeasuresSection: nil,
            socialHistorySection: nil,
            previousBirthsSection: nil,
            previousAbortionsSection: nil,
            expectedDateOfDeliverySection: nil,
            prenatalRiskAssessmentSection: nil,
            workEnvironmentImpactSection: nil,
            allergiesSection: nil,
            screeningsSection: nil,
            chronicDiseasesSection: nil,
            medicineSection: nil,
            mmrVaccinationSection: nil,
            historyOfPreviousTreatmentWithImpactOnPregnancySection: nil,
            tobaccoUseAndExposureSection: nil,
            alcoholDrinkingBehaviorSection: nil,
            assistedFertilizationSection: nil,
            substanceUseSection: nil,
            dietaryAndExerciseSection: nil,
            healthInsuranceSection: nil,
            birthPlaceSection: nil,
            midwifeClinicSection: nil,
            postpartumNursingSection: nil,
            overallAssessmentSection: nil,
            personalDataSection: nil,
            healthcareSection: nil
        )
    }
}
