// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import XCTest
import ErrorData
import HTTPMockHelpers
import GMAppData
@testable import MaternityServices

final class DataCardServiceImplTests: MaternityURLSessionMockTestCase {
    let dataCardService = DataCardServiceImpl()

    func testDataCard() {
        let url = URL(string: Self.config.maternityBaseUrl)!.appendingPathComponent("data-card")
        let testData = [
            DataCard(
                modifiedTime: Date(),
                author: HealthCareOrganization(name: "Test", sorId: "1234567890"),
                dirty: nil,
                episodeOfCareIdentifier: maternityId,
                documentUniqueId: nil,
                version: nil,
                documentStatus: .active,
                recordTarget: CprIdentifiedPerson(name: PersonName(firstNames: ["Test"], middleNames: [], lastName: "Testsen"), identifier: "123"),
                childPartnerSection: nil,
                languageSection: nil,
                bodyMeasuresSection: nil,
                socialHistorySection: nil,
                previousBirthsSection: nil,
                previousAbortionsSection: nil,
                expectedDateOfDeliverySection: nil,
                prenatalRiskAssessmentSection: nil,
                workEnvironmentImpactSection: nil,
                allergiesSection: nil,
                screeningsSection: nil,
                chronicDiseasesSection: nil,
                medicineSection: nil,
                mmrVaccinationSection: nil,
                historyOfPreviousTreatmentWithImpactOnPregnancySection: nil,
                tobaccoUseAndExposureSection: nil,
                alcoholDrinkingBehaviorSection: nil,
                assistedFertilizationSection: nil,
                substanceUseSection: nil,
                dietaryAndExerciseSection: nil,
                healthInsuranceSection: nil,
                birthPlaceSection: nil,
                midwifeClinicSection: nil,
                postpartumNursingSection: nil,
                overallAssessmentSection: nil,
                personalDataSection: nil,
                healthcareSection: nil
            )
        ]
        URLSessionStubResults.resultsForUrls[url] = .dataResponse(
            data: try! JSONEncoder.iso8601().encode(testData),
            response: URLSessionStubResponses.response(url: url)!
        )
        let expect = XCTestExpectation()

        dataCardService.fetchDataCards()
            .sink(
                receiveCompletion: { self.handleSubscriberCompletion($0, expectation: expect) },
                receiveValue: { dataCards in
                    XCTAssertEqual(1, dataCards.count)
                }
            )
            .store(in: &cancelBag)
        wait(for: [expect], timeout: 1.0)
    }
}
