#!/bin/bash

generation_folder="./OpenAPIGeneration"
models_base_folder="./MinGraviditet/Data/Sources/GMApp"
svn_checkout_folder="./YamlWorkplace"

function checkout {
    svn checkout "$1" "$svn_checkout_folder"
}

function generate {
    openapi-generator generate -i "$1" -g swift5 -o "$generation_folder/$2" --skip-validate-spec --global-property models --skip-overwrite
}

function copyToSourceLocation {
    mkdir -p "$models_base_folder"
    cp -a "$generation_folder/OpenAPIClient/Classes/OpenAPIs/Models/." "$models_base_folder"
}

function preCleanup {
    rm -rf "$models_base_folder/" # remove old source files
    postCleanup # make sure all workplace-folders are clean
}

function postCleanup {
    rm -rf "$generation_folder" # clean up generation folder
    rm -rf "$svn_checkout_folder" # clean up SVN folder
}

function checkIfToolsAreInstalled {
    local failed=false
    if ! [ -x "$(command -v openapi-generator)" ]; then
        echo '🛑  openapi-generator is not installed! ➡️ Run `brew install openapi-generator`' >&2
        failed=true
    fi

    if ! [ -x "$(command -v svn)" ]; then
        echo '🛑  svn is not installed! ➡️ Run `brew install subversion`' >&2
        failed=true
    fi

    if [ "$failed" = true ]; then
        exit 1
    fi
}

echo "🔧 Checking if required tools are installed on this machine ..."
checkIfToolsAreInstalled

echo "🚀 Starting generation of OpenAPI models..."
backendSvnRepo="https://svn.nspop.dk/src/libraries/gm/api/trunk/apis"
declare -a Urls=(
    "maternity-data/maternity-data-schema/src/main/resources/open-api/maternity-api.yaml"
    "maternity-feedback/maternity-feedback-schema/src/main/resources/open-api/FeedbackApi.yaml"
    "maternity-configuration/maternity-configuration-schema/src/main/resources/open-api/Configuration-api.yaml"
)

preCleanup
checkout $backendSvnRepo # SVN checks out files...
for i in "${Urls[@]}"; do
    set -- $i
    path="$1"

    echo "🔨 Starting generation of files for path: $path"
    generate "$svn_checkout_folder/$path" # Generates models in SVN location
    copyToSourceLocation # Moves them to another location
    echo "🏁 Finished generation for path: $path"
done
postCleanup

echo "✅ All done, all generated files were moved to: $models_base_folder"
